@@ -97,6 +97,8 @@ class HttpOTA:
             self.logger.info("Skipping check: %s < %s" % (self.format_time(now), self.format_time(next_scheduled_update)))
             status['success'] = True
 
+        self.logger.info(status)
+
         if status['success']:
             if status['updated']:
                 if status['need_reset']:
@@ -105,6 +107,8 @@ class HttpOTA:
                         machine.soft_reset()
                     else:
                         self.logger.warning("Reset requested and automatic_reset = False - Luck")
+            else:
+                self.logger.info("Seems like we didn't update anything")
         else:
             self.logger.warning("Update failed")
 
